@@ -91,7 +91,8 @@ def _save(path, types='fail'):
                 o.write(output)
             AdbCommand('%s -s %s pull /data/log/%s %s' % (bridge, serial, 'logcat.log', path)).run()
             AdbCommand('%s -s %s pull /data/log/%s %s' % (bridge, serial, 'logcat.log.1', path)).run()
-            #AdbCommand('%s -s %s pull /data/log/%s %s' % (bridge, serial, 'logcat.log.2', path)).run()
+            AdbCommand('%s -s %s pull /data/log/%s %s' % (bridge, serial, 'logcat.log.2', path)).run()
+            AdbCommand('%s -s %s pull /data/log/%s %s' % (bridge, serial, 'logcat.log.3', path)).run()
         else:
             if types == 'fail':
                 AdbCommand('%s shell screencap /sdcard/%s' % (bridge, FAILURE_SNAPSHOT_NAME)).run()
@@ -101,7 +102,8 @@ def _save(path, types='fail'):
                 o.write(output)
             AdbCommand('%s pull /data/log/%s %s' % (bridge, 'logcat.log', path)).run()
             AdbCommand('%s pull /data/log/%s %s' % (bridge, 'logcat.log.1', path)).run()
-            #AdbCommand('%s pull /data/log/%s %s' % (bridge, 'logcat.log.2', path)).run()       
+            AdbCommand('%s pull /data/log/%s %s' % (bridge, 'logcat.log.2', path)).run()
+            AdbCommand('%s pull /data/log/%s %s' % (bridge, 'logcat.log.3', path)).run()       
     except:
         pass
 
@@ -506,4 +508,4 @@ class FileOutputPlugin(nose.plugins.Plugin):
 
         self.result_properties.clear()
         self.result_properties.update({'name':case_dir_name, 'result':'pass', 'start_at':str(self.conf.case_start_time), 'end_at': str(datetime.datetime.now())})
-        _writeResultToFile(self.result_file, self.result_properties)
\ No newline at end of file
+        _writeResultToFile(self.result_file, self.result_properties)
